/*
 * Copyright (C) 2003 Red Flag Linux <jianxing@redflag-linux.com>
 */

#ifndef _EASYRPMPART_H_
#define _EASYRPMPART_H_

#include <kparts/part.h>
#include <qstringlist.h>
#include <qstring.h>

/**
 * This is a "Part".  It that does all the real work in a KPart
 * application.
 *
 * @short Main Part
 * @author root <root@localhost.localdomain>
 * @version 0.1
 */
namespace EasyRpm {
	enum {NOT, INSTALLED};
	enum {
	NODEPS		=0x000001,
	FORCE		=0x000002,
	TEST		=0x000004
	};
	
	enum {
	NAME		=0x000001,
	VER		=0x000002,
	RELEASE		=0x000004,
	SIZE		=0x000008,
	SUMMARY		=0x000010,
	ISSOURCE	=0x000020,
	ARCH		=0x000040,
	GROUP		=0x000080,
	DESCRIPTION	=0x000100,
	PACKAGER	=0x000200,
	LICENSE		=0x000400,
	URL		=0x000800,
	BUILDTIME	=0x001000,
	INSTALLTIME	=0x002000,
	BUILDHOST	=0x008000,
	ALL		=0xffffff
	};

class IEasyRpmPart : public KParts::ReadOnlyPart
{
    Q_OBJECT
public:
    /**     * Default constructor     */
	IEasyRpmPart(QObject *parent, const char *name, bool isFile)
	    :KParts::ReadOnlyPart(parent, name)
	    {}
	//until programm call info(), info will load and errors will be found and return;
	virtual bool import(const QStringList &names, unsigned int tags, QStringList &errs) = 0;
	//import and only load the "names" rpms info 
	virtual bool importLoad(const QStringList &names, unsigned int tags, QStringList &errs) = 0;
	//import and load all installed packages
	virtual bool importLoadAll(unsigned int tags, QStringList &errs) = 0;
	//virtual bool loadInfo(unsigned int tags, QStringList &errs, bool all = false) = 0;
	virtual void erase(const QString &name) = 0;
	virtual void clear(void) = 0;
	//virtual void setFile(bool isFile) = 0;//recommand not to use
	//virtual bool isFile(void) = 0;//recommand not to use
	virtual bool installedList(QStringList &names) = 0;

	//func
	virtual bool findRpmByFile(const QString &file, QStringList &ret) = 0;
	virtual bool verifyFilesInRpm(const QString &name, QStringList &ret) = 0;
	virtual bool doInstall(unsigned int flags, QStringList &errs, const QString &prefix) = 0;
	virtual bool doUninstall(const QStringList &names, unsigned int flags, QStringList &errs, const QString &rootdir) = 0;

	//get info
	virtual QStringList rpms(void) = 0;
	virtual QString info(const QString &name, unsigned int tag) = 0;
	virtual void getDeps(const QString &name, QStringList &ret) = 0;
	virtual void getFileList(const QString &name, QStringList &ret) = 0;
	virtual void getChangelog(const QString &name, QStringList &ret) = 0;
	virtual bool hasRpm(const QString name) = 0;//not in use

	//deal with string
	virtual QString path(const QString &path) = 0;
	virtual QString fileName(const QString &path) = 0;
	virtual QString packageName(const QString &path) = 0;
	virtual bool isSource(const QString &path) = 0;

	//property page
	virtual QWidget * drawPropertyPage(QWidget *parent, const char *name, const QString &rpmname) = 0;
	
	
signals:
	void installProgress(float prog);
public:
	struct RpmInfo{
		QString name;
		QString ver;
		QString release;
		QString size;
		QString summary;
		QString issource;
		QString arch;
		QString group;
		QString description;
		QString packager;
		QString license;
		QString url;
		QString buildtime;
		QString installtime;
		QString relocations;
		QString buildhost;
		QString signature;
	};
};

}//namespace

#endif
